@@ -347,7 +347,7 @@ static int _gnutls_find_acceptable_client_cert(gnutls_session session,
 		do {
 			/* This works like DECR_LEN() */
 			DECR_LENGTH_COM( dataptr_size, 2, goto clear);
-			size = _gnutls_read_uint16(data);
+			size = _gnutls_read_uint16(dataptr);
 
 			DECR_LENGTH_COM( dataptr_size, size, goto clear);
 
@@ -445,7 +445,8 @@ static int _gnutls_find_acceptable_client_cert(gnutls_session session,
 		 * This will make it relative to the certificates
 		 * we've got.
 		 */
-		indx = ij_map[indx];
+		if (indx != -1)
+			indx = ij_map[indx];
 
 	      clear:
 		gnutls_afree(my_certs);
@@ -1077,8 +1078,10 @@ int _gnutls_proc_cert_cert_req(gnutls_session session, opaque * data,
 	 */
 	session->internals.selected_cert_index = ind;
 
-	if (ind >= 0)
-		session->key->certificate_requested = 1;
+	/* We should reply with a certificate message,
+	 * even if we have no certificate to send.
+	 */
+	session->key->certificate_requested = 1;
 
 	return 0;
 }
@@ -1425,7 +1428,8 @@ static int _gnutls_server_find_cert_list_index(gnutls_session session,
 								 my_certs,
 								 my_certs_length);
 
-		index = ij_map[index];
+		if (index != -1)
+			index = ij_map[index];
 
 	      clear:
 		gnutls_free(my_certs);
