@@ -20,6 +20,7 @@
 #include <gcrypt.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <gnutls/openssl.h>
 
 /* WARNING: Error functions aren't currently thread-safe */
@@ -684,7 +685,7 @@ SSL_CIPHER *SSL_get_current_cipher(SSL *ssl)
     ssl->ciphersuite.kx = gnutls_kx_get(ssl->gnutls_state);
     ssl->ciphersuite.mac = gnutls_mac_get(ssl->gnutls_state);
     ssl->ciphersuite.compression = gnutls_compression_get(ssl->gnutls_state);
-    ssl->ciphersuite.cert = gnutls_cert_type_get(ssl->gnutls_state);
+    ssl->ciphersuite.cert = gnutls_certificate_type_get(ssl->gnutls_state);
 
     return &(ssl->ciphersuite);
 }
@@ -811,7 +812,7 @@ void X509_free(const X509 *cert)
 
 /* BIO functions */
 
-void BIO_get_fd(GNUTLS_STATE gnutls_state, int *fd)
+void BIO_get_fd(gnutls_session gnutls_state, int *fd)
 {
     *fd = gnutls_transport_get_ptr(gnutls_state);
 }
